@@ -4,17 +4,12 @@ import joblib
 import numpy as np
 from pkg_resources import resource_filename
 import fire
-import warnings
-import logging
-
-logging.basicConfig(level=logging.INFO)
 
 
 class Regbot:
   reg_model_path = resource_filename(__name__, 'finalized_model.h5') 
-  model_scaler_path = resource_filename(__name__, 'logscaler.gz')
-  thr = 0.2833333333333333
-
+  model_scaler_path = resource_filename(__name__, 'logscaler.gz') 
+  thr = 0.3
 
   def __init__(self,*args):
   	pass
@@ -51,9 +46,7 @@ class Regbot:
 
 def signal(opening,closing):
   try:
-    with warnings.catch_warnings():
-      warnings.filterwarnings("ignore")
-      return Regbot.buySignalGenerator(opening,closing)
+    return Regbot.buySignalGenerator(opening,closing)
   except Exception as e:
     print(e)
 
